@@ -35,10 +35,11 @@ class RatedMiddleware(object):
 
         client = redis.Redis(connection_pool=POOL)
         # Do commands at once for speed
+        # This also wraps them in a transaction, so they operate atomically
         pipe = client.pipeline()
         # Add our timestamp to the range
         pipe.zadd(key, now, now)
-        # Update to not expire for another hour
+        # Update to not expire for another TIMEOUT
         pipe.expireat(key, int(now + conf.get('timeout', settings.DEFAULT_TIMEOUT)))
         # Remove old values
         pipe.zremrangebyscore(key, '-inf', now - settings.DEFAULT_TIMEOUT)
@@ -46,5 +47,7 @@ class RatedMiddleware(object):
         pipe.zcard(key)
         size = pipe.execute()[-1]
         if size > conf.get('limit', settings.DEFAULT_LIMIT):
-            return HttpResponse(status=429)
+            return HttpResponse(conf.get('message', settings.RESPONSE_MESSAGE),
+                status=conf.get('code', settings.RESPONSE_CODE, 429)
+            )
         return None
